/*
 * Copyright (C) 2021 Damir Porobic <damir.porobic@gmx.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KSNIP_CLIPBOARDMOCK_H
#define KSNIP_CLIPBOARDMOCK_H

#include <gmock/gmock.h>

#include "src/gui/clipboard/IClipboard.h"

class ClipboardMock : public IClipboard
{
public:
	MOCK_METHOD(QPixmap, pixmap, (), (const, override));
	MOCK_METHOD(bool, isPixmap, (), (const, override));
	MOCK_METHOD(void, setImage, (const QImage &image), (override));
	MOCK_METHOD(void, setText, (const QString &text), (override));
	MOCK_METHOD(QString, url, (), (const, override));
};

#endif //KSNIP_CLIPBOARDMOCK_H
