/*
 * Copyright (C) 2020 Damir Porobic <damir.porobic@gmx.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KSNIP_FILEDIALOGADAPTER_H
#define KSNIP_FILEDIALOGADAPTER_H

#include <QFileDialog>

#include "IFileDialogService.h"

class FileDialogAdapter : public IFileDialogService
{
public:
	explicit FileDialogAdapter() = default;
	~FileDialogAdapter() override = default;
	QString	getExistingDirectory(QWidget *parent, const QString &title, const QString &directory) override;
	QString	getOpenFileName(QWidget *parent, const QString &title, const QString &directory) override;
	QStringList	getOpenFileNames(QWidget *parent, const QString &title, const QString &directory, const QString &filter) override;
	QString	getSavePath(QWidget *parent, const QString &title, const QString &path, const QString &filter) override;

protected:
	void addOption(QFileDialog::Option option);

private:
	QFileDialog::Options mOptions;
};

#endif //KSNIP_FILEDIALOGADAPTER_H
